Files
project_6/cccl_upstream/cudax/test/stf/threads/axpy-threads-graph.cu
muh-bot dedf08166a [CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout:
- c2h/ (27 files): Catch2 test helpers — generators, validators, runner
- nvbench_helper/ (10 files): Benchmark harness utilities
- cmake/ (29 files): CMake presets and build helpers
- cudax/ (794 files): Experimental CUDA extensions
- AGENTS.md: NVIDIA's official AI agent instructions for CCCL
- CMakePresets.json: Standardized build configurations
- cccl-version.json: Version tracking

Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to
competition value and PRD items.

cccl_upstream now covers 100% of competition-critical assets:
- 27 tuning headers (SM80/90/100 benchmark data)
- 32 dispatch headers (algorithm implementations)
- 60 Thrust examples (correctness verification)
- 217 CUB Catch2 tests (regression matrix)
- 153 CUB benchmarks (parameter space search)
- 18 CUB examples (API verification)
- 27 test helpers + benchmark harness
- 794 cudax experimental extensions
2026-08-06 02:14:18 +00:00

75 lines
1.6 KiB
Plaintext

//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
/**
* @file
*
* @brief Ensure a graph_ctx can be used concurrently
*
*/
#include <cuda/experimental/stf.cuh>
#include <mutex>
#include <thread>
using namespace cuda::experimental::stf;
void mytask(graph_ctx ctx, int /*id*/)
{
const size_t N = 16;
int alpha = 3;
auto lX = ctx.logical_data<int>(N);
auto lY = ctx.logical_data<int>(N);
ctx.parallel_for(lX.shape(), lX.write(), lY.write())->*[] __device__(size_t i, auto x, auto y) {
x(i) = (1 + i);
y(i) = (2 + i * i);
};
/* Compute Y = Y + alpha X */
for (size_t i = 0; i < 200; i++)
{
ctx.parallel_for(lY.shape(), lY.rw(), lX.read())->*[alpha] __device__(size_t i, auto dY, auto dX) {
dY(i) += alpha * dX(i);
};
}
ctx.host_launch(lX.read(), lY.read())->*[alpha](auto x, auto y) {
for (size_t i = 0; i < N; i++)
{
EXPECT(x(i) == 1 + i);
EXPECT(y(i) == 2 + i * i + 200 * alpha * x(i));
}
};
}
int main()
{
graph_ctx ctx;
::std::vector<::std::thread> threads;
// Launch threads
for (int i = 0; i < 10; ++i)
{
threads.emplace_back(mytask, ctx, i);
}
// Wait for all threads to complete.
for (auto& th : threads)
{
th.join();
}
ctx.finalize();
}